==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/inputs/ListAppServicePlanHybridConnectionKeysPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin.inputs

import com.pulumi.azurenative.web.inputs.ListAppServicePlanHybridConnectionKeysPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property name Name of the App Service plan.
 * @property namespaceName The name of the Service Bus namespace.
 * @property relayName The name of the Service Bus relay.
 * @property resourceGroupName Name of the resource group to which the resource belongs.
 */
public data class ListAppServicePlanHybridConnectionKeysPlainArgs(
    public val name: String,
    public val namespaceName: String,
    public val relayName: String,
    public val resourceGroupName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.web.inputs.ListAppServicePlanHybridConnectionKeysPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.web.inputs.ListAppServicePlanHybridConnectionKeysPlainArgs =
        com.pulumi.azurenative.web.inputs.ListAppServicePlanHybridConnectionKeysPlainArgs.builder()
            .name(name.let({ args0 -> args0 }))
            .namespaceName(namespaceName.let({ args0 -> args0 }))
            .relayName(relayName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [ListAppServicePlanHybridConnectionKeysPlainArgs].
 */
@PulumiTagMarker
public class ListAppServicePlanHybridConnectionKeysPlainArgsBuilder internal constructor() {
    private var name: String? = null

    private var namespaceName: String? = null

    private var relayName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value Name of the App Service plan.
     */
    @JvmName("vmgamwwkjvinrwhq")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.name = mapped
    }

    /**
     * @param value The name of the Service Bus namespace.
     */
    @JvmName("gwxuvrxkjjcqrjid")
    public suspend fun namespaceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.namespaceName = mapped
    }

    /**
     * @param value The name of the Service Bus relay.
     */
    @JvmName("fgcpubagsavoxhts")
    public suspend fun relayName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.relayName = mapped
    }

    /**
     * @param value Name of the resource group to which the resource belongs.
     */
    @JvmName("lsnmmwukfcvmlehy")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): ListAppServicePlanHybridConnectionKeysPlainArgs =
        ListAppServicePlanHybridConnectionKeysPlainArgs(
            name = name ?: throw PulumiNullFieldException("name"),
            namespaceName = namespaceName ?: throw PulumiNullFieldException("namespaceName"),
            relayName = relayName ?: throw PulumiNullFieldException("relayName"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/inputs/ListAppServicePlanHybridConnectionKeysPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin.inputs

import com.pulumi.azurenative.web.inputs.ListAppServicePlanHybridConnectionKeysPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property name Name of the App Service plan.
 * @property namespaceName The name of the Service Bus namespace.
 * @property relayName The name of the Service Bus relay.
 * @property resourceGroupName Name of the resource group to which the resource belongs.
 */
public data class ListAppServicePlanHybridConnectionKeysPlainArgs(
    public val name: String,
    public val namespaceName: String,
    public val relayName: String,
    public val resourceGroupName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.web.inputs.ListAppServicePlanHybridConnectionKeysPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.web.inputs.ListAppServicePlanHybridConnectionKeysPlainArgs =
        com.pulumi.azurenative.web.inputs.ListAppServicePlanHybridConnectionKeysPlainArgs.builder()
            .name(name.let({ args0 -> args0 }))
            .namespaceName(namespaceName.let({ args0 -> args0 }))
            .relayName(relayName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [ListAppServicePlanHybridConnectionKeysPlainArgs].
 */
@PulumiTagMarker
public class ListAppServicePlanHybridConnectionKeysPlainArgsBuilder internal constructor() {
    private var name: String? = null

    private var namespaceName: String? = null

    private var relayName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value Name of the App Service plan.
     */
    @JvmName("eiuywnnsgstmbyey")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.name = mapped
    }

    /**
     * @param value The name of the Service Bus namespace.
     */
    @JvmName("akqkbkkoigxxshcs")
    public suspend fun namespaceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.namespaceName = mapped
    }

    /**
     * @param value The name of the Service Bus relay.
     */
    @JvmName("snloewaifelssfxj")
    public suspend fun relayName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.relayName = mapped
    }

    /**
     * @param value Name of the resource group to which the resource belongs.
     */
    @JvmName("udiqxaaqmduineln")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): ListAppServicePlanHybridConnectionKeysPlainArgs =
        ListAppServicePlanHybridConnectionKeysPlainArgs(
            name = name ?: throw PulumiNullFieldException("name"),
            namespaceName = namespaceName ?: throw PulumiNullFieldException("namespaceName"),
            relayName = relayName ?: throw PulumiNullFieldException("relayName"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        )
}
